clear all;clc; 

% check if direcory exista then create directory

%% getting data 

prompt = {'Enter a value of the gate reistance in \bf case 1 \rm (in \Omega):',...
    'Enter a value of the gate reistance in \bf case 2 \rm (in \Omega):'};
dlgtitle = 'Gate resistance values in cases 1 and 2';
dims = [1 75];
definput = {'150','1e3'}; % definput = {'',''};
opts.Interpreter = 'tex';
answer = inputdlg(prompt,dlgtitle,dims,definput,opts);

Rval = [str2num(answer{1}), str2num(answer{2})];

%% running cases 

f = waitbar(0,'Simulating... please wait!');

% Case 1 (Rg1 = Rg2 = 150 Ohm)
load_system('Lab2');
set_param('Lab2/Half-bridge/Rg1','R','Rval(1)'); % changing Rg1 value
set_param('Lab2/Half-bridge/Rg2','R','Rval(1)'); % changing Rg2 value
case1 = sim('Lab2'); % running simulation 

% Case 1 (Rg1 = Rg2 = 1000 Ohm)
f = waitbar(0.5,f,'Simulating... please wait!');
set_param('Lab2/Half-bridge/Rg1','R','Rval(2)'); % changing Rg1 value
set_param('Lab2/Half-bridge/Rg2','R','Rval(2)'); % changing Rg2 value
case2 = sim('Lab2'); % running simulation 

close(f);
%% get the variables

% getting vcariables for case 1
uref.case1 = case1.ScopeData.signals(1).values(:,1);
utri.case1 = case1.ScopeData.signals(1).values(:,2);

G1.case1 = case1.ScopeData.signals(2).values(:,1);
G2.case1 = case1.ScopeData.signals(2).values(:,2);

Id1.case1 = case1.ScopeData.signals(3).values(:,1);
Id2.case1 = case1.ScopeData.signals(3).values(:,2);

Vds1.case1 = case1.ScopeData.signals(4).values(:,1);
Vds2.case1 = case1.ScopeData.signals(4).values(:,2);

Vgg1.case1 = case1.ScopeData.signals(5).values(:,1);
Vgs1.case1 = case1.ScopeData.signals(5).values(:,2);
Vgg2.case1 = case1.ScopeData.signals(5).values(:,3);
Vgs2.case1 = case1.ScopeData.signals(5).values(:,4);

Ig1.case1 = case1.ScopeData.signals(6).values(:,1);
Ig2.case1 = case1.ScopeData.signals(6).values(:,2);

tout.case1 = case1.tout;

% getting vcariables for case 2
uref.case2 = case2.ScopeData.signals(1).values(:,1);
utri.case2 = case2.ScopeData.signals(1).values(:,2);

G1.case2 = case2.ScopeData.signals(2).values(:,1);
G2.case2 = case2.ScopeData.signals(2).values(:,2);

Id1.case2 = case2.ScopeData.signals(3).values(:,1);
Id2.case2 = case2.ScopeData.signals(3).values(:,2);

Vds1.case2 = case2.ScopeData.signals(4).values(:,1);
Vds2.case2 = case2.ScopeData.signals(4).values(:,2);

Vgg1.case2 = case2.ScopeData.signals(5).values(:,1);
Vgs1.case2 = case2.ScopeData.signals(5).values(:,2);
Vgg2.case2 = case2.ScopeData.signals(5).values(:,3);
Vgs2.case2 = case2.ScopeData.signals(5).values(:,4);

Ig1.case2 = case2.ScopeData.signals(6).values(:,1);
Ig2.case2 = case2.ScopeData.signals(6).values(:,2);

tout.case2 = case2.tout;

%% plots Q1

figure(10); clf; 

tiledlayout(5,2);
textwidth = 14.9;
texthight = 24;
figsize = [textwidth, texthight];

ax(1) = nexttile(1);
plot(tout.case1 - 5.1676e-5, Vgg1.case1, tout.case2 - 5.1676e-5, Vgg1.case2)
ylabel('$V_{gg(1)}$ [V]','Interpreter','latex');
legend('Case 1','Case 2');
legend('Interpreter','latex');
title('\bf Turn-on \rm Transient for $Q_1$','Interpreter','latex');
box off;

ax(2) = nexttile(3);
plot(tout.case1 - 5.1676e-5, Vgs1.case1, tout.case2 - 5.1676e-5, Vgs1.case2)
ylabel('$V_{gs(1)}$ [V]','Interpreter','latex');
box off;

ax(3) = nexttile(5);
plot(tout.case1 - 5.1676e-5, Ig1.case1, tout.case2 - 5.1676e-5, Ig1.case2)
ylabel('$I_{g(1)}$ [A]','Interpreter','latex');
box off;

ax(4) = nexttile(7);
plot(tout.case1 - 5.1676e-5, Id1.case1, tout.case2 - 5.1676e-5, Id1.case2)
ylabel('$I_{q(1)}$ [A]','Interpreter','latex');
box off;

ax(5) = nexttile(9);
plot(tout.case1 - 5.1676e-5, Vds1.case1, tout.case2 - 5.1676e-5, Vds1.case2)
ylabel('$V_{ds(1)}$ [V]','Interpreter','latex');
xlabel('$t$ [s]','Interpreter','latex');
box off;

linkaxes(ax,'x'); xlim([-0.176 2.5]*1e-6);
clear ax;

ax(1) = nexttile(2);
plot(tout.case1 - 9.862e-5, Vgg1.case1, tout.case2 - 9.862e-5, Vgg1.case2)
ylabel('$V_{gg(1)}$ [V]','Interpreter','latex');
legend('Case 1','Case 2');
legend('Interpreter','latex');
title('\bf Turn-off \rm Transient for $Q_1$','Interpreter','latex');
box off;

ax(2) = nexttile(4);
plot(tout.case1 - 9.862e-5, Vgs1.case1, tout.case2 - 9.862e-5, Vgs1.case2)
ylabel('$V_{gs(1)}$ [V]','Interpreter','latex');
box off;

ax(3) = nexttile(6);
plot(tout.case1 - 9.862e-5, Ig1.case1, tout.case2 - 9.862e-5, Ig1.case2)
ylabel('$I_{g(1)}$ [A]','Interpreter','latex');
box off;

ax(4) = nexttile(8);
plot(tout.case1 - 9.862e-5, Id1.case1, tout.case2 - 9.862e-5, Id1.case2)
ylabel('$I_{q(1)}$ [A]','Interpreter','latex');
box off;

ax(5) = nexttile(10);
plot(tout.case1 - 9.862e-5, Vds1.case1, tout.case2 - 9.862e-5, Vds1.case2)
ylabel('$V_{ds(1)}$ [V]','Interpreter','latex');
xlabel('$t$ [s]','Interpreter','latex');
box off;

linkaxes(ax,'x'); xlim([-1e-8 9e-8]);
clear ax;

h = findall(gcf,'Type','axes'); % An array if you have subplots
set(h, 'TickLabelInterpreter', 'latex')

% Set size and no crop
set(gcf, 'PaperUnits', 'centimeters', 'PaperSize', figsize);
set(gcf, 'PaperUnits', 'normalized', 'PaperPosition', [0, 0, 1, 1]);

% print -dpdf results_Lab2_Q1_trans.pdf
print -dbmp results_Lab2_Q1_trans.bmp

%% plots Q2

figure(11); clf; 

tiledlayout(5,2);
textwidth = 14.9;
texthight = 24;
figsize = [textwidth, texthight];

ax(1) = nexttile(1);
plot(tout.case1 - 1.0063e-4, Vgg2.case1, tout.case2 - 1.0063e-4, Vgg2.case2)
ylabel('$V_{gg(2)}$ [V]','Interpreter','latex');
legend('Case 1','Case 2');
legend('Interpreter','latex');
title('\bf Turn-on \rm Transient for $Q_2$','Interpreter','latex');
box off;

ax(2) = nexttile(3);
plot(tout.case1 - 1.0063e-4, Vgs2.case1, tout.case2 - 1.0063e-4, Vgs2.case2)
ylabel('$V_{gs(2)}$ [V]','Interpreter','latex');
box off;

ax(3) = nexttile(5);
plot(tout.case1 - 1.0063e-4, Ig2.case1, tout.case2 - 1.0063e-4, Ig2.case2)
ylabel('$I_{g(2)}$ [A]','Interpreter','latex');
box off;

ax(4) = nexttile(7);
plot(tout.case1 - 1.0063e-4, Id2.case1, tout.case2 - 1.0063e-4, Id2.case2)
ylabel('$I_{q(1)}$ [A]','Interpreter','latex');
box off;

ax(5) = nexttile(9);
plot(tout.case1 - 1.0063e-4, Vds2.case1, tout.case2 - 1.0063e-4, Vds2.case2)
ylabel('$V_{ds(2)}$ [V]','Interpreter','latex');
xlabel('$t$ [s]','Interpreter','latex');
box off;

linkaxes(ax,'x'); xlim([-2.5e-6 3e-6]);
clear ax;

ax(1) = nexttile(2);
plot(tout.case1 - 4.9695e-5, Vgg2.case1, tout.case2 - 4.9695e-5, Vgg2.case2)
ylabel('$V_{gg(2)}$ [V]','Interpreter','latex');
legend('Case 1','Case 2');
legend('Interpreter','latex');
title('\bf Turn-off \rm Transient for $Q_2$','Interpreter','latex');
box off;

ax(2) = nexttile(4);
plot(tout.case1 - 4.9695e-5, Vgs2.case1, tout.case2 - 4.9695e-5, Vgs2.case2)
ylabel('$V_{gs(2)}$ [V]','Interpreter','latex');
box off;

ax(3) = nexttile(6);
plot(tout.case1 - 4.9695e-5, Ig2.case1, tout.case2 - 4.9695e-5, Ig2.case2)
ylabel('$I_{g(2)}$ [A]','Interpreter','latex');
box off;

ax(4) = nexttile(8);
plot(tout.case1 - 4.9695e-5, Id2.case1, tout.case2 - 4.9695e-5, Id2.case2)
ylabel('$I_{q(2)}$ [A]','Interpreter','latex');
box off;

ax(5) = nexttile(10);
plot(tout.case1 - 4.9695e-5, Vds2.case1, tout.case2 - 4.9695e-5, Vds2.case2)
ylabel('$V_{ds(2)}$ [V]','Interpreter','latex');
xlabel('$t$ [s]','Interpreter','latex');
box off;

linkaxes(ax,'x'); xlim([-1e-7 4e-6]);
clear ax;

h = findall(gcf,'Type','axes'); % An array if you have subplots
set(h, 'TickLabelInterpreter', 'latex')

% Set size and no crop
set(gcf, 'PaperUnits', 'centimeters', 'PaperSize', figsize);
set(gcf, 'PaperUnits', 'normalized', 'PaperPosition', [0, 0, 1, 1]);

% print -dpdf results_Lab2_Q2_trans.pdf
print -dbmp results_Lab2_Q2_trans.bmp
